@@ -16,9 +16,9 @@ txt2man -d "$T2M_DATE" -t $T2M_NAME -r $T2M_NAME-$T2M_VERSION -s $T2M_LEVEL -v "
 #--------------------------------------------------------
 
 # Put here all data for your first manpage (in T2M lines)
-T2M_DATE="17 Apr 2023"
+T2M_DATE="20 Oct 2024"
 T2M_NAME=dcfldd
-T2M_VERSION=1.9.1
+T2M_VERSION=1.9.2
 T2M_LEVEL=1
 T2M_DESC="enhanced version of dd for forensics and security"
 create-man
