@@ -3,7 +3,8 @@
  * By Nicholas Harbour
  */
 
-/* Copyright (C) 85, 90, 91, 1995-2001, 2005 Free Software Foundation, Inc.
+/* Copyright 85, 90, 91, 1995-2001, 2005 Free Software Foundation, Inc.
+   Copyright 2022                        Tibor Szolnoki <szolnoki.tibor@gmail.com>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -24,6 +25,6 @@
 #ifndef FULL_WRITE_H
 #define FULL_WRITE_H
 
-int full_write(int, const char *, size_t);
+int full_write(int, const char *, size_t, int diffwr);
 
 #endif /* FULL_WRITE_H */
