@@ -32,6 +32,10 @@
    the function fails to perform the requested operation.  In that case,
    lseek should return nonzero and set errno.  */
 
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
 #include "dcfldd.h"
 #include <sys/types.h>
 #include <sys/wait.h>
@@ -116,7 +120,8 @@ void skip2(int fdesc, char *file, uintmax_t records, size_t blocksize,
 
 #ifdef __linux__
 
-# include <error.h>
+# include "dcfldd_error.h"
+
 # include <sys/mtio.h>
 
 # define MT_SAME_POSITION(P, Q) \
@@ -140,7 +145,7 @@ static off_t skip_via_lseek(char const *filename, int fdesc, off_t offset,
         && ioctl (fdesc, MTIOCGET, &s2) == 0
         && MT_SAME_POSITION (s1, s2))
     {
-        error (0, 0, _("warning: working around lseek kernel bug for file (%s)\n\
+        dcfldd_error (0, 0, _("warning: working around lseek kernel bug for file (%s)\n\
   of mt_type=0x%0lx -- see <sys/mtio.h> for the list of types"),
                filename, s2.mt_type);
         errno = 0;
